package net.knarcraft.minecraftserverlauncher.userinterface;

import net.knarcraft.minecraftserverlauncher.Main;
import net.knarcraft.minecraftserverlauncher.profile.ServerLauncherController;

import javax.swing.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

/**
 * Listener for clicking the close button of a server tab
 */
public class CloseTabActionListener implements ActionListener {

    private final String tabName;
    private final JTabbedPane tabPane;

    /**
     * Instantiates a new close tab action listener
     *
     * @param tabPane <p>The tab pane containing all tabs</p>
     * @param tabName <p>The name of the tab connected to this action listener</p>
     */
    public CloseTabActionListener(JTabbedPane tabPane, String tabName) {
        this.tabName = tabName;
        this.tabPane = tabPane;
    }

    @Override
    public void actionPerformed(ActionEvent evt) {
        int index = tabPane.indexOfTab(tabName);
        if (index >= 0) {
            //Abort if the user just mis-clicked
            int answer = JOptionPane.showConfirmDialog(null,
                    String.format("Do you really want to remove the server %s?", tabName), "Remove server",
                    JOptionPane.YES_NO_OPTION
            );
            if (answer == JOptionPane.YES_NO_OPTION) {
                //Remove the server
                ServerLauncherController controller = Main.getController();
                controller.getCurrentProfile().removeCollection(tabName);
                controller.getGUI().updateWithSavedProfileData();
                controller.getCurrentProfile().updateConsoles();
            }
        }
    }

}